==> qastools_1.1.0.orig.tar.xz: qastools-v1.1.0/shared/src/wdg/fill_columns_layout.hpp <==
/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include <QLayout>
#include <QStyle>
#include <vector>

namespace Wdg
{

/// @brief Fill_Columns_Layout_Item
///
class Fill_Columns_Layout_Item
{
  public:
  // -- Construction

  Fill_Columns_Layout_Item () = default;

  ~Fill_Columns_Layout_Item () = default;

  QLayoutItem * item = nullptr;
  QSize min_size;
  QRect rect;
};

/// @brief Fill_Columns_Layout
///
class Fill_Columns_Layout : public QLayout
{
  // Public methods
  public:
  // -- Construction

  Fill_Columns_Layout ( QWidget * parent_n = nullptr );

  ~Fill_Columns_Layout ();

  // -- Size hints

  QSize
  sizeHint () const override;

  QSize
  minimumSize () const override;

  bool
  hasHeightForWidth () const;

  int
  heightForWidth ( int width ) const;

  // Spacings

  int
  horizontal_spacing () const;

  int
  vertical_spacing () const;

  unsigned int
  horizontal_spacing_default () const;

  unsigned int
  vertical_spacing_default () const;

  unsigned int
  spacing_default ( Qt::Orientation orient_n ) const;

  // Viewport geometry

  const QRect &
  viewport_geometry () const
  {
    return _viewport;
  }

  void
  set_viewport_geometry ( const QRect & rect_n );

  // Layout methods

  QLayoutItem *
  itemAt ( int index_n ) const;

  int
  count () const;

  void
  addItem ( QLayoutItem * item_n );

  QLayoutItem *
  takeAt ( int index_n );

  void
  invalidate ();

  void
  setGeometry ( const QRect & rect_n );

  // Protected methods
  protected:
  void
  update_cache_const () const;

  void
  update_cache ();

  QSize
  calc_columns ( unsigned int width_n, unsigned int height_n );

  // Private attributes
  private:
  ::std::vector< Fill_Columns_Layout_Item > _items;

  QRect _viewport;

  int _hspace;
  int _vspace;

  bool _cache_dirty;
};

} // namespace Wdg

==> qastools_1.2.0.orig.tar.xz: qastools-v1.2.0/shared/src/wdg/fill_columns_layout.hpp <==
/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include <QLayout>
#include <QStyle>
#include <vector>

namespace Wdg
{

/// @brief Fill_Columns_Layout_Item
///
class Fill_Columns_Layout_Item
{
  public:
  // -- Construction

  Fill_Columns_Layout_Item () = default;

  ~Fill_Columns_Layout_Item () = default;

  QLayoutItem * item = nullptr;
  QSize min_size;
  QRect rect;
};

/// @brief Fill_Columns_Layout
///
class Fill_Columns_Layout : public QLayout
{
  public:
  // -- Construction

  Fill_Columns_Layout ( QWidget * parent_n = nullptr );

  ~Fill_Columns_Layout ();

  // -- Size hints

  QSize
  sizeHint () const override;

  QSize
  minimumSize () const override;

  bool
  hasHeightForWidth () const;

  int
  heightForWidth ( int width ) const;

  // Spacings

  int
  horizontal_spacing () const;

  int
  vertical_spacing () const;

  unsigned int
  horizontal_spacing_default () const;

  unsigned int
  vertical_spacing_default () const;

  unsigned int
  spacing_default ( Qt::Orientation orient_n ) const;

  // Viewport geometry

  const QRect &
  viewport_geometry () const
  {
    return _viewport;
  }

  void
  set_viewport_geometry ( const QRect & rect_n );

  // Layout methods

  QLayoutItem *
  itemAt ( int index_n ) const;

  int
  count () const;

  void
  addItem ( QLayoutItem * item_n );

  QLayoutItem *
  takeAt ( int index_n );

  void
  invalidate ();

  void
  setGeometry ( const QRect & rect_n );

  protected:
  // -- Protected methods

  void
  update_cache_const () const;

  void
  update_cache ();

  QSize
  calc_columns ( unsigned int width_n, unsigned int height_n );

  private:
  // -- Attributes
  std::vector< Fill_Columns_Layout_Item > _items;

  QRect _viewport;

  int _hspace;
  int _vspace;

  bool _cache_dirty;
};

} // namespace Wdg
